referrerpolicy=no-referrer-when-downgrade

kick_member

Function kick_member 

pub fn kick_member<T: Config<I>, I: 'static>(who: AccountIdLookupOf<T>)
Kick a member from the society. Callable only by the Signed origin of the Founder.

The member is fully removed (not suspended). All unclaimed payouts are slashed and returned to the society pot.

Parameters:

  • who: The member to be removed.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::kick_member.