referrerpolicy=no-referrer-when-downgrade

poke_deposit

Function poke_deposit 

pub fn poke_deposit<T: Config<I>, I: 'static>()
Poke the deposit reserved when bidding.

The dispatch origin for this call must be Signed and must be the bidder.

The transaction fee is waived if the deposit is changed after poking/reconsideration.

Emits DepositPoked if successful.

Warning: Doc-Only

This function is an automatically generated, and is doc-only, uncallable stub. See the real version in Pallet::poke_deposit.